@@ -21,7 +21,7 @@ def download_file(url, file_name=None):
         file_name = f"{file_name}.ipynb"
 
     file_name = f"dl_{file_name}"
-    if "github.com" in raw_target:
+    if "://github.com" in raw_target:
         raw_target = raw_target.replace(
             "https://github.com/", "https://raw.githubusercontent.com/"
         )
@@ -30,14 +30,19 @@ def download_file(url, file_name=None):
     if "://" not in raw_target:
         try:
             cur_path = os.path.join(
-                n_env.path_naas_folder, n_env.server_root, raw_target
+                f"{n_env.path_naas_folder}{n_env.server_root}", raw_target
             )
             ff = open(cur_path, "rb")
             content = ff.read()
             ff.close()
         except Exception as e:
             print(f"Cannot open local file {cur_path}", e)
-            content = b"ERROR: Cannot open local file " + bytes(raw_target, "utf-8")
+            content = (
+                b"ERROR: Cannot open local file "
+                + bytes(cur_path, "utf-8")
+                + b" "
+                + bytes(raw_target, "utf-8")
+            )
     else:
         r = requests.get(raw_target)
         content = r.content
