@@ -1,8 +1,18 @@
-from naas.types import t_scheduler, t_start, t_main, t_health, t_error, t_busy, t_delete
+from naas.ntypes import (
+    t_scheduler,
+    t_start,
+    t_main,
+    t_health,
+    t_error,
+    t_busy,
+    t_delete,
+)
 from apscheduler.schedulers.asyncio import AsyncIOScheduler
+from naas.callback import Callback
 import apscheduler.schedulers.base
 from .env_var import n_env
 import traceback
+import requests
 import datetime
 import asyncio
 import aiohttp
@@ -10,6 +20,7 @@ import pycron
 import time
 import pytz
 import uuid
+import os
 
 
 async def fetch(url):
@@ -38,6 +49,7 @@ class Scheduler:
             return "paused"
 
     def stop(self):
+        print("Stop scheduler")
         if self.__scheduler is not None:
             self.__scheduler.pause()
             self.__scheduler.remove_job(n_env.scheduler_job_name)
@@ -221,6 +233,63 @@ class Scheduler:
                 t_error,
             )
 
+    def getTerminals(self):
+        try:
+            r = requests.get(
+                f"{n_env.user_url}/api/terminals",
+                headers={
+                    "Authorization": f"token {n_env.token}",
+                },
+            )
+            r.raise_for_status()
+            return r.json()
+        except Exception as e:
+            print(e)
+            return {}
+
+    def getSessions(self):
+        try:
+            r = requests.get(
+                f"{n_env.user_url}/api/sessions",
+                headers={
+                    "Authorization": f"token {n_env.token}",
+                },
+            )
+            r.raise_for_status()
+            return r.json()
+        except Exception as e:
+            print(e)
+            return {}
+
+    async def analytics(self, uid):
+        try:
+            curdate = datetime.datetime.now().strftime("%Y%m%d%H%M%S%f")
+            data = {
+                "date": curdate,
+                "gpu": os.environ.get("NAAS_GPU", "NO"),
+                "jobs": await self.__jobs.list(uid),
+                "kernels": self.getSessions(),
+                "terminals": self.getTerminals(),
+            }
+            Callback().add(
+                auto_delete=False,
+                uuid=f"naas_analytics__{curdate}",
+                default_result=data,
+                no_override=True,
+            )
+        except Exception as e:
+            tb = traceback.format_exc()
+            self.__logger.error(
+                {
+                    "id": uid,
+                    "type": t_scheduler,
+                    "filepath": "analytics",
+                    "status": t_error,
+                    "error": str(e),
+                    "trace": tb,
+                }
+            )
+
     async def __scheduler_function(self):
         # Create unique for scheduling step (one step every minute)
         main_uid = str(uuid.uuid4())
@@ -264,6 +333,7 @@ class Scheduler:
                     "duration": duration_total,
                 }
             )
+            await self.analytics(main_uid)
         except Exception as e:
             tb = traceback.format_exc()
             duration_total = time.time() - all_start_time
